@@ -74,7 +74,11 @@ def create_server_version_variants() -> list[BuildVariant]:
     for version in ALL_VERSIONS:
         display_name = get_variant_name("* MongoDB", version=version)
         variant = create_variant(
-            [".server-version"], display_name, host=DEFAULT_HOST, tags=["coverage_tag"]
+            [".server-version"],
+            display_name,
+            version=version,
+            host=DEFAULT_HOST,
+            tags=["coverage_tag"],
         )
         variants.append(variant)
     return variants
