@@ -267,7 +267,7 @@ class APITestsMixin:
 
     # $changeStream.startAtOperationTime was added in 4.0.0.
     @no_type_check
-    @async_client_context.require_version_min(4, 0, 0)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_start_at_operation_time(self):
         optime = await self.get_start_at_operation_time()
 
@@ -436,7 +436,7 @@ class APITestsMixin:
             await self._test_get_invalidate_event(change_stream)
 
     @no_type_check
-    @async_client_context.require_version_min(4, 1, 1)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_start_after(self):
         resume_token = await self.get_resume_token(invalidate=True)
 
@@ -452,7 +452,7 @@ class APITestsMixin:
             self.assertEqual(change["fullDocument"], {"_id": 2})
 
     @no_type_check
-    @async_client_context.require_version_min(4, 1, 1)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_start_after_resume_process_with_changes(self):
         resume_token = await self.get_resume_token(invalidate=True)
 
@@ -563,27 +563,16 @@ class ProseSpecTestsMixin:
                 )
 
     # Prose test no. 1
-    @async_client_context.require_version_min(4, 0, 7)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_update_resume_token(self):
         await self._test_update_resume_token(self._get_expected_resume_token)
 
-    # Prose test no. 1
-    @async_client_context.require_version_max(4, 0, 7)
-    async def test_update_resume_token_legacy(self):
-        await self._test_update_resume_token(self._get_expected_resume_token_legacy)
-
     # Prose test no. 2
-    @async_client_context.require_version_min(4, 1, 8)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_raises_error_on_missing_id_418plus(self):
         # Server returns an error on 4.1.8+
         await self._test_raises_error_on_missing_id(OperationFailure)
 
-    # Prose test no. 2
-    @async_client_context.require_version_max(4, 1, 8)
-    async def test_raises_error_on_missing_id_418minus(self):
-        # PyMongo raises an error
-        await self._test_raises_error_on_missing_id(InvalidOperation)
-
     # Prose test no. 3
     @no_type_check
     async def test_resume_on_error(self):
@@ -642,40 +631,12 @@ class ProseSpecTestsMixin:
             cursor.close = raise_error
             await self.insert_one_and_check(change_stream, {"_id": 2})
 
-    # Prose test no. 9
-    @no_type_check
-    @async_client_context.require_version_min(4, 0, 0)
-    @async_client_context.require_version_max(4, 0, 7)
-    async def test_start_at_operation_time_caching(self):
-        # Case 1: change stream not started with startAtOperationTime
-        client, listener = self.client_with_listener("aggregate")
-        async with await self.change_stream_with_client(client) as cs:
-            await self.kill_change_stream_cursor(cs)
-            await cs.try_next()
-        cmd = listener.started_events[-1].command
-        self.assertIsNotNone(cmd["pipeline"][0]["$changeStream"].get("startAtOperationTime"))
-
-        # Case 2: change stream started with startAtOperationTime
-        listener.reset()
-        optime = await self.get_start_at_operation_time()
-        async with await self.change_stream_with_client(
-            client, start_at_operation_time=optime
-        ) as cs:
-            await self.kill_change_stream_cursor(cs)
-            await cs.try_next()
-        cmd = listener.started_events[-1].command
-        self.assertEqual(
-            cmd["pipeline"][0]["$changeStream"].get("startAtOperationTime"),
-            optime,
-            str([k.command for k in listener.started_events]),
-        )
-
     # Prose test no. 10 - SKIPPED
     # This test is identical to prose test no. 3.
 
     # Prose test no. 11
     @no_type_check
-    @async_client_context.require_version_min(4, 0, 7)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_resumetoken_empty_batch(self):
         client, listener = await self._client_with_listener("getMore")
         async with await self.change_stream_with_client(client) as change_stream:
@@ -687,7 +648,7 @@ class ProseSpecTestsMixin:
 
     # Prose test no. 11
     @no_type_check
-    @async_client_context.require_version_min(4, 0, 7)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_resumetoken_exhausted_batch(self):
         client, listener = await self._client_with_listener("getMore")
         async with await self.change_stream_with_client(client) as change_stream:
@@ -697,38 +658,6 @@ class ProseSpecTestsMixin:
         response = listener.succeeded_events[-1].reply
         self.assertEqual(resume_token, response["cursor"]["postBatchResumeToken"])
 
-    # Prose test no. 12
-    @no_type_check
-    @async_client_context.require_version_max(4, 0, 7)
-    async def test_resumetoken_empty_batch_legacy(self):
-        resume_point = await self.get_resume_token()
-
-        # Empty resume token when neither resumeAfter or startAfter specified.
-        async with await self.change_stream() as change_stream:
-            await change_stream.try_next()
-            self.assertIsNone(change_stream.resume_token)
-
-        # Resume token value is same as resumeAfter.
-        async with await self.change_stream(resume_after=resume_point) as change_stream:
-            await change_stream.try_next()
-            resume_token = change_stream.resume_token
-            self.assertEqual(resume_token, resume_point)
-
-    # Prose test no. 12
-    @no_type_check
-    @async_client_context.require_version_max(4, 0, 7)
-    async def test_resumetoken_exhausted_batch_legacy(self):
-        # Resume token is _id of last change.
-        async with await self.change_stream() as change_stream:
-            change = await self._populate_and_exhaust_change_stream(change_stream)
-            self.assertEqual(change_stream.resume_token, change["_id"])
-            resume_point = change["_id"]
-
-        # Resume token is _id of last change even if resumeAfter is specified.
-        async with await self.change_stream(resume_after=resume_point) as change_stream:
-            change = await self._populate_and_exhaust_change_stream(change_stream)
-            self.assertEqual(change_stream.resume_token, change["_id"])
-
     # Prose test no. 13
     @no_type_check
     async def test_resumetoken_partially_iterated_batch(self):
@@ -770,13 +699,13 @@ class ProseSpecTestsMixin:
     # Prose test no. 14
     @no_type_check
     @async_client_context.require_no_mongos
-    @async_client_context.require_version_min(4, 1, 1)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_resumetoken_uniterated_nonempty_batch_startafter(self):
         await self._test_resumetoken_uniterated_nonempty_batch("start_after")
 
     # Prose test no. 17
     @no_type_check
-    @async_client_context.require_version_min(4, 1, 1)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_startafter_resume_uses_startafter_after_empty_getMore(self):
         # Resume should use startAfter after no changes have been returned.
         resume_point = await self.get_resume_token()
@@ -796,7 +725,7 @@ class ProseSpecTestsMixin:
 
     # Prose test no. 18
     @no_type_check
-    @async_client_context.require_version_min(4, 1, 1)
+    @async_client_context.require_version_min(4, 2, 0)
     async def test_startafter_resume_uses_resumeafter_after_nonempty_getMore(self):
         # Resume should use resumeAfter after some changes have been returned.
         resume_point = await self.get_resume_token()
@@ -843,7 +772,7 @@ class ProseSpecTestsMixin:
 class TestClusterAsyncChangeStream(TestAsyncChangeStreamBase, APITestsMixin):
     dbs: list
 
-    @async_client_context.require_version_min(4, 0, 0, -1)
+    @async_client_context.require_version_min(4, 2, 0)
     @async_client_context.require_change_streams
     async def asyncSetUp(self) -> None:
         await super().asyncSetUp()
@@ -903,7 +832,7 @@ class TestClusterAsyncChangeStream(TestAsyncChangeStreamBase, APITestsMixin):
 
 
 class TestAsyncDatabaseAsyncChangeStream(TestAsyncChangeStreamBase, APITestsMixin):
-    @async_client_context.require_version_min(4, 0, 0, -1)
+    @async_client_context.require_version_min(4, 2, 0)
     @async_client_context.require_change_streams
     async def asyncSetUp(self) -> None:
         await super().asyncSetUp()
